@@ -4,6 +4,7 @@ Mlflow server inside ML_management.
 ML_manager sends request to our server on /mlflow endpoint
 Server calls original mlflow function accordingly
 """
+import atexit
 import inspect
 import io
 import os
@@ -109,6 +110,7 @@ def start_run(
 
 def log_model(
     artifact_path,
+    action_type,  # "train"/"finetune"/"upload"
     loader_module=None,
     data_path=None,
     code_path=None,
@@ -121,6 +123,8 @@ def log_model(
     await_registration_for=DEFAULT_AWAIT_MAX_SLEEP_SECONDS,
     pip_requirements=None,
     extra_pip_requirements=None,
+    source_model_name=None,
+    source_model_version=None,
 ):
     """
     Log a Pyfunc model with custom inference logic and optional data dependencies as an MLflow artifact.
@@ -221,6 +225,9 @@ def end_run(status: str = finished_run_status) -> None:
         active_run_stack.pop()
 
 
+atexit.register(end_run)
+
+
 class MlflowClient(object):
     """Initialize an MLflow Client."""
 
