@@ -20,7 +20,7 @@ from mlflow.store.entities import PagedList
 # noinspection PyUnresolvedReferences
 
 
-# TODO how do we test that?
+# TODO maybe make it singleton?
 
 
 class RegistryManager:
@@ -29,8 +29,8 @@ class RegistryManager:
     def __init__(self):
         self.client = mlmanagement.MlflowClient()
 
-    def __check_model_registered(self, name: str) -> RegisteredModel:
-        # utility method for checking if model is registered or not
+    def check_model_registered(self, name: str) -> RegisteredModel:
+        """Check if model is registered in mlflow or not."""
         try:
             registered_model = self.client.get_registered_model(name)
         except RestException as err:
@@ -40,9 +40,10 @@ class RegistryManager:
                 raise err
         return registered_model
 
-    def __get_latest_version(self, name: str, stage: str = "None") -> ModelVersion:
+    def get_latest_version(self, name: str, stage: str = "None") -> ModelVersion:
+        """Get latest version of a model "name"."""
         latest_version = None
-        registered_model = self.__check_model_registered(name)
+        registered_model = self.check_model_registered(name)
 
         for mv in registered_model.latest_versions:
             if mv.current_stage == stage:
@@ -54,17 +55,17 @@ class RegistryManager:
             # model is registered, but no versions on stage
             raise NoVersionsOnStage(name, stage)
 
-    def __get_best_version(
+    def get_best_version(
         self,
         name: str,
         metric: str,
-        criteria: str,
         optimal_min: bool = False,
         stage: str = "None",
     ) -> ModelVersion:
+        """Get best version of model "name" according to a metric."""
         # optimal_min parameter is to look for minimal value of metric, max by default
         current_best_version, current_best_score = None, None
-        self.__check_model_registered(name)
+        self.check_model_registered(name)
         model_versions = self.client.search_model_versions(
             filter_string=f"name = '{name}'"
         )
@@ -95,7 +96,8 @@ class RegistryManager:
         else:
             raise MetricNotLogged(name, metric)
 
-    def __get_initial_version(self, name: str, stage: str = "None") -> ModelVersion:
+    def get_initial_version(self, name: str, stage: str = "None") -> ModelVersion:
+        """Get initial version of model "name"."""
         #  TODO need some mechanism to identify that model is initially uploaded. Only fetch minimal version for now.
         model_versions = self.get_all_versions(name)
 
@@ -107,16 +109,29 @@ class RegistryManager:
         min_version = min(model_versions_on_stage, key=attrgetter("version"))
         return min_version
 
-    def __get_version(self, name: str, version: str) -> ModelVersion:
+    def get_version(self, name: str, version: int) -> ModelVersion:
+        """
+        Get model version from MLflow Model Registry and return its ModelVersion object.
+
+        https://mlflow.org/docs/latest/python_api/mlflow.entities.html#mlflow.entities.model_registry.ModelVersion
+
+        Parameters:
+            name (str): Model name used for model registration.
+            version (int): Desired version number.
+
+        Returns:
+            ModelVersion: Desired model version
+
+        """
         # first, check that model is registered
-        self.__check_model_registered(name)
+        self.check_model_registered(name)
         # now, try to retrieve desired version
         try:
-            model_version = self.client.get_model_version(name, version)
+            model_version = self.client.get_model_version(name, str(version))
         except RestException as err:
             if err.error_code == "RESOURCE_DOES_NOT_EXIST":
                 # model is registered, but version is not found
-                raise VersionNotFound(name, version)
+                raise VersionNotFound(name, str(version))
             else:
                 raise err
 
@@ -137,37 +152,13 @@ class RegistryManager:
         Returns:
             PagedList[ModelVersion]: Available model versions
         """
-        self.__check_model_registered(name)
+        self.check_model_registered(name)
         model_versions = self.client.search_model_versions(
             filter_string=f"name = '{name}'"
         )
 
         return model_versions
 
-    def get_version(
-        self,
-        *,
-        name: str,
-        version: int,
-    ) -> ModelVersion:
-        """
-        Get model version from MLflow Model Registry and return its ModelVersion object.
-
-        https://mlflow.org/docs/latest/python_api/mlflow.entities.html#mlflow.entities.model_registry.ModelVersion
-
-        Parameters:
-            name (str): Model name used for model registration.
-            version (int): Desired version number.
-
-        Returns:
-            ModelVersion: Desired model version
-
-        """
-        return self.__get_version(
-            name=name,
-            version=str(version),  # version is required to be int in str format
-        )
-
     def choose_version(
         self,
         *,
@@ -200,13 +191,12 @@ class RegistryManager:
         # for now, return single path and no name choosing -- model name must be explicitly passed
         # TODO in the future make name resolvers and return list of paths, one per chosen name
         version_fetcher_map = {
-            "initial": self.__get_initial_version,
-            "latest": self.__get_latest_version,
+            "initial": self.get_initial_version,
+            "latest": self.get_latest_version,
             "best": partial(
-                self.__get_best_version,
+                self.get_best_version,
                 metric=metric,
                 optimal_min=optimal_min,
-                criteria=criteria,
             ),
         }
         if criteria == "best" and metric is None:
